tsseg.algorithms.ggs package
============================

Models each segment as multivariate Gaussian, greedy splitting + optional refinement.

| **Type:** change point detection
| **Supervision:** semi-supervised
| **Scope:** models full covariance

**Implementation:** Adapted from Stanford CVX Group. BSD 2-Clause.

**Reference:** Hallac, Nystrup & Boyd (2019), ADAC.

Submodules
----------

tsseg.algorithms.ggs.detector module
------------------------------------

.. automodule:: tsseg.algorithms.ggs.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.ggs
   :members:
   :show-inheritance:
   :undoc-members:
